import {
  AKElement,
  EVENT_SIDEBAR_TOGGLE,
  QUERY_MEDIA_COLOR_LIGHT,
  UiThemeEnum,
  WithBrandConfig,
  button_default,
  page_default,
  patternfly_base_default,
  rootInterface,
  t
} from "./chunk-AMC4UCMS.js";
import {
  i,
  ke
} from "./chunk-XFT4DB4U.js";
import {
  __decorateClass
} from "./chunk-KZ3QJOBN.js";

// src/elements/utils/images.ts
function themeImage(rawPath) {
  let enabledTheme = rootInterface()?.activeTheme;
  if (!enabledTheme || enabledTheme === UiThemeEnum.Automatic) {
    enabledTheme = window.matchMedia(QUERY_MEDIA_COLOR_LIGHT).matches ? UiThemeEnum.Light : UiThemeEnum.Dark;
  }
  return rawPath.replaceAll("%(theme)s", enabledTheme);
}

// src/elements/sidebar/SidebarBrand.ts
var MIN_WIDTH = 1200;
var DefaultBrand = {
  brandingLogo: "/static/dist/assets/icons/icon_left_brand.svg",
  brandingFavicon: "/static/dist/assets/icons/icon.png",
  brandingTitle: "authentik",
  uiFooterLinks: [],
  uiTheme: UiThemeEnum.Automatic,
  matchedDomain: "",
  defaultLocale: ""
};
var SidebarBrand = class extends WithBrandConfig(AKElement) {
  static get styles() {
    return [
      patternfly_base_default,
      patternfly_base_default,
      page_default,
      button_default,
      i`
                :host {
                    display: flex;
                    flex-direction: row;
                    align-items: center;
                    height: 114px;
                    min-height: 114px;
                }
                .pf-c-brand img {
                    padding: 0 0.5rem;
                    height: 42px;
                }
                button.pf-c-button.sidebar-trigger {
                    background-color: transparent;
                    border-radius: 0px;
                    height: 100%;
                    color: var(--ak-dark-foreground);
                }
            `
    ];
  }
  constructor() {
    super();
    window.addEventListener("resize", () => {
      this.requestUpdate();
    });
  }
  render() {
    return ke` ${window.innerWidth <= MIN_WIDTH ? ke`
                      <button
                          class="sidebar-trigger pf-c-button"
                          @click=${() => {
      this.dispatchEvent(
        new CustomEvent(EVENT_SIDEBAR_TOGGLE, {
          bubbles: true,
          composed: true
        })
      );
    }}
                      >
                          <i class="fas fa-bars"></i>
                      </button>
                  ` : ke``}
            <a href="#/" class="pf-c-page__header-brand-link">
                <div class="pf-c-brand ak-brand">
                    <img
                        src=${themeImage(this.brand?.brandingLogo ?? DefaultBrand.brandingLogo)}
                        alt="authentik Logo"
                        loading="lazy"
                    />
                </div>
            </a>`;
  }
};
SidebarBrand = __decorateClass([
  t("ak-sidebar-brand")
], SidebarBrand);

export {
  DefaultBrand
};
//# sourceMappingURL=chunk-EOXPQFQF.js.map
