import {
  button_default
} from "./chunk-E4FQAZYR.js";
import {
  form_control_default,
  form_default,
  login_default
} from "./chunk-RVW7F5SR.js";
import {
  BaseStage,
  title_default,
  to
} from "./chunk-QUIJSWK4.js";
import {
  patternfly_base_default,
  r,
  t
} from "./chunk-EQUF5YAR.js";
import {
  ke,
  msg
} from "./chunk-BL2WZFD2.js";
import {
  __decorateClass
} from "./chunk-QTFYAG5J.js";

// src/flow/stages/captcha/CaptchaStage.ts
var captchaContainerID = "captcha-container";
var CaptchaStage = class extends BaseStage {
  constructor() {
    super();
    this.handlers = [this.handleGReCaptcha, this.handleHCaptcha, this.handleTurnstile];
    this.captchaInteractive = true;
    this.captchaContainer = document.createElement("div");
    this.captchaContainer.id = captchaContainerID;
  }
  static get styles() {
    return [patternfly_base_default, login_default, form_default, form_control_default, title_default, button_default];
  }
  updated(changedProperties) {
    if (changedProperties.has("challenge") && this.challenge !== void 0) {
      this.scriptElement = document.createElement("script");
      this.scriptElement.src = this.challenge.jsUrl;
      this.scriptElement.async = true;
      this.scriptElement.defer = true;
      this.scriptElement.dataset.akCaptchaScript = "true";
      this.scriptElement.onload = () => {
        console.debug("authentik/stages/captcha: script loaded");
        let found = false;
        let lastError = void 0;
        this.handlers.forEach((handler) => {
          let handlerFound = false;
          try {
            console.debug(`authentik/stages/captcha[${handler.name}]: trying handler`);
            handlerFound = handler.apply(this);
            if (handlerFound) {
              console.debug(
                `authentik/stages/captcha[${handler.name}]: handler succeeded`
              );
              found = true;
            }
          } catch (exc) {
            console.debug(
              `authentik/stages/captcha[${handler.name}]: handler failed: ${exc}`
            );
            if (handlerFound) {
              lastError = exc;
            }
          }
        });
        if (!found && lastError) {
          this.error = lastError.toString();
        }
      };
      document.head.querySelectorAll("[data-ak-captcha-script=true]").forEach((el) => el.remove());
      document.head.appendChild(this.scriptElement);
    }
  }
  handleGReCaptcha() {
    if (!Object.hasOwn(window, "grecaptcha")) {
      return false;
    }
    this.captchaInteractive = false;
    document.body.appendChild(this.captchaContainer);
    grecaptcha.ready(() => {
      const captchaId = grecaptcha.render(this.captchaContainer, {
        sitekey: this.challenge.siteKey,
        callback: (token) => {
          this.host?.submit({
            token
          });
        },
        size: "invisible"
      });
      grecaptcha.execute(captchaId);
    });
    return true;
  }
  handleHCaptcha() {
    if (!Object.hasOwn(window, "hcaptcha")) {
      return false;
    }
    this.captchaInteractive = false;
    document.body.appendChild(this.captchaContainer);
    const captchaId = hcaptcha.render(this.captchaContainer, {
      sitekey: this.challenge.siteKey,
      size: "invisible",
      callback: (token) => {
        this.host?.submit({
          token
        });
      }
    });
    hcaptcha.execute(captchaId);
    return true;
  }
  handleTurnstile() {
    if (!Object.hasOwn(window, "turnstile")) {
      return false;
    }
    this.captchaInteractive = false;
    document.body.appendChild(this.captchaContainer);
    window.turnstile.render(`#${captchaContainerID}`, {
      sitekey: this.challenge.siteKey,
      callback: (token) => {
        this.host?.submit({
          token
        });
      }
    });
    return true;
  }
  renderBody() {
    if (this.error) {
      return ke`<ak-empty-state icon="fa-times" header=${this.error}> </ak-empty-state>`;
    }
    if (this.captchaInteractive) {
      return ke`${this.captchaContainer}`;
    }
    return ke`<ak-empty-state loading header=${msg("Verifying...")}></ak-empty-state>`;
  }
  render() {
    if (!this.challenge) {
      return ke`<ak-empty-state loading> </ak-empty-state>`;
    }
    return ke`<header class="pf-c-login__main-header">
                <h1 class="pf-c-title pf-m-3xl">${this.challenge.flowInfo?.title}</h1>
            </header>
            <div class="pf-c-login__main-body">
                <form class="pf-c-form">
                    <ak-form-static
                        class="pf-c-form__group"
                        userAvatar="${this.challenge.pendingUserAvatar}"
                        user=${this.challenge.pendingUser}
                    >
                        <div slot="link">
                            <a href="${to(this.challenge.flowInfo?.cancelUrl)}"
                                >${msg("Not you?")}</a
                            >
                        </div>
                    </ak-form-static>
                    ${this.renderBody()}
                </form>
            </div>
            <footer class="pf-c-login__main-footer">
                <ul class="pf-c-login__main-footer-links"></ul>
            </footer>`;
  }
};
__decorateClass([
  r()
], CaptchaStage.prototype, "error", 2);
__decorateClass([
  r()
], CaptchaStage.prototype, "captchaInteractive", 2);
__decorateClass([
  r()
], CaptchaStage.prototype, "captchaContainer", 2);
__decorateClass([
  r()
], CaptchaStage.prototype, "scriptElement", 2);
CaptchaStage = __decorateClass([
  t("ak-stage-captcha")
], CaptchaStage);

export {
  CaptchaStage
};
//# sourceMappingURL=chunk-URZYSK63.js.map
